@@ -5,9 +5,9 @@
 __package_name__ = __name__
 __app_name__ = 'Kast'
 __app_description__ = "Cast videos (with subtitles) straight from your PC."
-__app_url__ = "https://bitbucket.org/massultidev/kast/src/master/"
+__app_url__ = "https://bitbucket.org/massultidev/kast/"
 
-__version_info__ = (1, 0, 3)
+__version_info__ = (1, 1, 1)
 __version__ = '.'.join([str(i) for i in __version_info__])
 
 __author__ = 'P.J. Grochowski'
