@@ -3,6 +3,7 @@
 # Copyright by: P.J. Grochowski
 
 import os
+import platform
 import sys
 
 from PyQt5 import Qt
@@ -19,13 +20,14 @@ from kast.utils.Loggable import Loggable
 class KastQtApp(Loggable):
 
     def __init__(self, services: Services) -> None:
-        setupQt()
+        self._setupQt()
         self._app = QApplication(sys.argv)
         self._uiServices = UiServices(services)
 
         self._app.setWindowIcon(QIcon(str(services.settings.appIconPath)))
+        self._setupPlatform()
 
-        self._mainWindowController = MainWindowViewModel(uiServices=self._uiServices)
+        self._mainWindowViewModel = MainWindowViewModel(uiServices=self._uiServices)
 
         self._app.aboutToQuit.connect(self._onExit)
 
@@ -41,14 +43,20 @@ class KastQtApp(Loggable):
         self.log.info("Interface exit.")
         self._uiServices.uiEventObserver.notify(UiEvent(state=UiState.Closing, progress=Progress(complete=False)))
 
+    def _setupPlatform(self) -> None:
+        """Platform specific setup. Should be run after QApplication creation."""
 
-def setupQt() -> None:
-    """Should be run before QApplication creation."""
+        if platform.system() == 'Linux':
+            self._app.setDesktopFileName(self._uiServices.services.settings.desktopFileName)
 
-    # On windows default backend for media support is 'directshow'.
-    # Which does not provide support for proprietary codecs like 'h264'.
-    # We could change to 'windowsmediafoundation' backend instead.
-    # Unfortunately this setup will only work for Qt>=5.15.5.
-    # Workaround for older versions is to install a codec pack.
-    if os.name == 'nt':
-        os.environ['QT_MULTIMEDIA_PREFERRED_PLUGINS'] = 'windowsmediafoundation'
+    @staticmethod
+    def _setupQt() -> None:
+        """Qt framework setup. Should be run before QApplication creation."""
+
+        # On windows default backend for media support is 'directshow'.
+        # Which does not provide support for proprietary codecs like 'h264'.
+        # We could change to 'windowsmediafoundation' backend instead.
+        # Unfortunately this setup will only work for Qt>=5.15.5.
+        # Workaround for older versions is to install a codec pack.
+        if os.name == 'nt':
+            os.environ['QT_MULTIMEDIA_PREFERRED_PLUGINS'] = 'windowsmediafoundation'
