@@ -13,6 +13,7 @@ from kast.interface.qt5.view.MediaControlView import Ui_MediaControlView
 from kast.interface.qt5.viewModel.VideoPreviewViewModel import VideoPreviewViewModel
 from kast.interface.qt5.viewModel.ViewModelBase import ViewBase, ViewModelBase
 from kast.media.casting.CastState import CastMediaState, CastPlayerState, CastState, Seconds
+from kast.utils.chrono import Milliseconds
 
 
 class View(ViewBase, QWidget, Ui_MediaControlView):
@@ -21,8 +22,6 @@ class View(ViewBase, QWidget, Ui_MediaControlView):
 
 class MediaControlViewModel(ViewModelBase):
 
-    SEEK_DELTA = Seconds(10)
-
     def __init__(
         self,
         parent: QWidget,
@@ -45,7 +44,7 @@ class MediaControlViewModel(ViewModelBase):
         self._view.buttonMuteLocal.setIcon(self._view.style().standardIcon(QStyle.SP_MediaVolume))
 
         self._videoPositionUpdater = QTimer()
-        self._videoPositionUpdater.setInterval(1_000)
+        self._videoPositionUpdater.setInterval(int(Milliseconds(Seconds(1))))
         self._videoPositionUpdater.timeout.connect(self._signalVideoPositionUpdate)
         self._videoPositionUpdater.start()
 
@@ -121,28 +120,25 @@ class MediaControlViewModel(ViewModelBase):
         self.services.castController.disconnect()
 
     def _signalClickedPlayPause(self) -> None:
-        if self._mediaState.isPlaying():
-            self.services.castController.pause()
-        else:
-            self.services.castController.play()
+        self.uiServices.mediaControlService.playOrPause()
 
     def _signalClickedStop(self) -> None:
-        self.services.castController.stop()  # TODO: Make it possible to replay movie!
+        self.uiServices.mediaControlService.stop()
 
     def _signalClickedSeekForward(self) -> None:
-        self.services.castController.seek(timePos=Seconds(self._view.sliderSeek.value()) + self.SEEK_DELTA)
+        self.uiServices.mediaControlService.seekForward()
 
     def _signalClickedSeekBackward(self) -> None:
-        self.services.castController.seek(timePos=Seconds(self._view.sliderSeek.value()) - self.SEEK_DELTA)
+        self.uiServices.mediaControlService.seekBackward()
 
     def _signalSeekPosition(self) -> None:
-        self.services.castController.seek(timePos=Seconds(self._view.sliderSeek.value()))
+        self.uiServices.mediaControlService.seek(Seconds(self._view.sliderSeek.value()))
 
     def _signalClickedMuteRemote(self) -> None:
-        self.services.castController.setMute(not self._mediaState.volumeMuted)
+        self.uiServices.mediaControlService.setMute(not self._mediaState.volumeMuted)
 
     def _signalSetVolumeRemote(self) -> None:
-        self.services.castController.setVolume(val=self._view.sliderVolumeRemote.value()/100)
+        self.uiServices.mediaControlService.setVolume(self._view.sliderVolumeRemote.value()/100)
 
     def _signalClickedMuteLocal(self) -> None:
         self._videoPreviewViewModel.muted = not self._videoPreviewViewModel.muted
