@@ -25,6 +25,7 @@ class CastController(
     ConnectionStatusListener
 ):
     TIMEOUT = Seconds(10)
+    SEEK_DELTA = Seconds(10)
 
     def __init__(
         self,
@@ -166,6 +167,12 @@ class CastController(
         mediaController = self._mediaController
         mediaController and mediaController.seek(timePos.value)
 
+    def seekForward(self) -> None:
+        self.seek(self._castState.mediaState.adjustedPosition + self.SEEK_DELTA)
+
+    def seekBackward(self) -> None:
+        self.seek(self._castState.mediaState.adjustedPosition - self.SEEK_DELTA)
+
     def _setupDevice(self, device: pychromecast.Chromecast) -> None:
         if device.cast_type != pychromecast.CAST_TYPE_CHROMECAST:
             raise CastException(f"Device '{device.name}' does not support video casting!")
